unit DAVAO;
{----------------------------------------------------------------
Part of Diagramantics VSL Framework (DAVSL)
www.diagramantics.com

This unit contains all the types and constants from VAO.H translated to Delphi.
Based on VAO.pas translated by:
*  Ravelin
*  http://www.ravelin.nl

Note that VAO.H and VAO.C contain many useful comments, indeed form one of the
main sources of documentation on the VSL interface, so you will want to be
familiar with them if you decide to modify DAVSL extensively.

The functionality implemented in VAO.C is replaced by DAVSL.pas

Revision History
-----------------
2000-09-02 GW: Trimmed down Ravelin's VAO.pas and made a few changes.
               Replaced implementation section with functionality in DAVSL  

-----------------------------------------------------------------}

//======================================
              interface
//======================================

// Version of the VSL inteface defined herein.
const
  VAO_IFMAJOR = $0002;           // Major interface version number.
  VAO_IFMINOR = $0003;           // Minor interface version number.

//----------------------------------------------
// Visio callback (ie: to Visio)
//----------------------------------------------
type
  TVAORC = word;                // Visio Add-on Return code.
  TVAOMsg = word;               // Visio Add-on Message code.
  PVAOFunc = ^TVAOFunc;
  TVAOFunc = function(msgAction: TVAOMsg; wParam: word; lpParam: pointer): TVAORC; cdecl;

//----------------------------------------------
// For AddOn Registration function
//----------------------------------------------

//.................................
// TVAORegRecord.ord
//.................................
type
  // PVAO_Ordinal = ^TVAO_Ordinal;
  TVAO_Ordinal = word;
const
  VAO_INV_ORD = 0;

//.................................
// TVAORegRecord.atts
//.................................
type
  // PVAO_Atts = ^TVAO_Atts;
  TVAO_Atts = word;

const
  VAO_AOATTS_ISACTION = $0001;  // Add-on performs actions.
  VAO_AOATTS_HASABOUT = $0002;  // Add-on supplies an about for itself
  VAO_AOATTS_HASHELP  = $0004;  // Add-on supplies help about itself.
  VAO_AOATTS_WAITCRSR = $0008;  // Keep wait cursor up when Add-on runs.
  VAO_AOATTS_DONTSHOW = $0010;  // Don't show addon in menus/dialogs.

//.................................
// TVAORegRecord.enabMask
//.................................
type
  // PVAO_EnabMask = ^TVAO_EnabMask;
  TVAO_EnabMask = word;

const
  // Basic Enabledness determination strategy
  VAO_ENABLEALWAYS = $FFFF;     // Add-on is always enabled.
  VAO_ENABLEDYNAMIC = 0;        // Visio should query V2LMSG_ISAOENABLED
  VAO_ENABLEDYNAMICEX = $8000;  // Check Needs then V2LMSG_ISAOENABLED
                                // Add-on should respond VAORC_L2V_ENABLED or 0.

  // Needs
  _VAO_ND     = $0001;          // Add-on needs a document.
  _VAO_NW     = $0002;          // Add-on needs a window.
  _VAO_NDrW   = $0004;          // Add-on needs a draw window.
  _VAO_NStW   = $0008;          // Add-on needs a stencil window.
  _VAO_NShW   = $0010;          // Add-on needs a sheet window.
  _VAO_NIcW   = $0020;          // Add-on needs an icon window.
  _VAO_NT     = $0040;          // Add-on needs a target context.
  _VAO_NPgT   = $0080;          // Add-on needs target that is a page.
  _VAO_NMsT   = $0100;          // Add-on needs target that is a master.
  _VAO_NS     = $0200;          // Add-on needs a selection.

  VAO_NEEDSDOC           = _VAO_ND;
  VAO_NEEDSDOCWND        = _VAO_ND or _VAO_NW;
  VAO_NEEDSDRAWWND       = _VAO_ND or _VAO_NW or _VAO_NDrW;
  VAO_NEEDSPAGEWND       = _VAO_ND or _VAO_NW or _VAO_NDrW or _VAO_NPgT;
  VAO_NEEDSMASTERWND     = _VAO_ND or _VAO_NW or _VAO_NDrW or _VAO_NMsT;
  VAO_NEEDSSTENWND       = _VAO_ND or _VAO_NW or _VAO_NStW;
  VAO_NEEDSSHEETWND      = _VAO_ND or _VAO_NW or _VAO_NShW;
  VAO_NEEDSICONWND       = _VAO_ND or _VAO_NW or _VAO_NIcW;
  VAO_NEEDSTARGET        = _VAO_ND or _VAO_NT;
  VAO_NEEDSTARGPAGE      = _VAO_ND or _VAO_NT or _VAO_NPgT;
  VAO_NEEDSTARGMASTER    = _VAO_ND or _VAO_NT or _VAO_NMsT;
  VAO_NEEDSSELECTION     = _VAO_ND or _VAO_NT or _VAO_NS;

//.................................
// TVAORegRecord.invokeOnMask
//.................................
type
  // PVAO_InvokeMask = ^TVAO_InvokeMask;
  TVAO_InvokeMask = word;
const
  VAO_INVOKE_LAUNCH = $0001;

//.................................
// TVAORegRecord.notifyOnMask
//.................................
type
  // PVAO_NotifyMask = ^TVAO_NotifyMask;
  TVAO_NotifyMask = word;

//.................................
// TVAORegRecord
//.................................
const
  VAOMAXAONAME = 100;
type
  PVAORegRecord = ^TVAORegRecord;
  //-----------------------------
  TVAORegRecord = packed record
  //-----------------------------
      ord: TVAO_Ordinal;                 // Ordinal of Add-on. Unique, non VAO_INV_ORD.
      atts: TVAO_Atts;                   // Attributes of Add-on.
      enabMask: TVAO_EnabMask;           // Add-on's enabling policy.
      invokeOnMask: TVAO_InvokeMask;     // Invoke conditions
      notifyOnMask: TVAO_NotifyMask;     // notify conditions (none?)
      lpName: PChar;                     // Add-on's name. Visio makes a copy. ANSI
    end;


const
  VAO_INV_SESSID = $FFFF;


//----------------------------------------------
// VisioLibMain() input structure (VAOV2LSTRUCT)
//----------------------------------------------
type
  PVAOV2LRecord = ^TVAOV2LRecord;
  //-----------------------------
  TVAOV2LRecord = packed record
  //-----------------------------
      hVisInst: integer;   // THandle?  But Application_.Instance32 is useless anyway
      lpfunc: PVAOFunc;
      wSessID: word;
      lpArgs: pointer;
      lpCmdLineArgs: PChar;
    end;

//----------------------------------------------
// Message constants
//----------------------------------------------

const
  _VAOGEN_INVBASE   = $0000;    // First invariant generic message/rc
  _VAOGEN_SENBASE   = $1000;    // First int sensitive generic message/rc

  _V2L_INVBASE      = $2000;    // First invariant v2l message/rc
  _V2L_SENBASE      = $3000;    // First int sensitive v2l message/rc

  _L2V_INVBASE      = $4000;    // First invariant l2v message/rc
  _L2V_SENBASE      = $5000;    // First int sensitive l2v message/rc

  INVALID_VAOMSG             = _VAOGEN_INVBASE;   // The code no msg can have.

  // Messages that Visio sends to a VSL:
  V2LMSG_LOAD                = _V2L_INVBASE;
  V2LMSG_UNLOAD              = _V2L_INVBASE + 1;
  V2LMSG_ENUMADDONS          = _V2L_SENBASE;
  V2LMSG_ISAOENABLED         = _V2L_SENBASE + 1;
  V2LMSG_RUN                 = _V2L_SENBASE + 2;
  V2LMSG_RUNABOUT            = _V2L_SENBASE + 3;
  V2LMSG_RUNHELP             = _V2L_SENBASE + 4;
  V2LMSG_KILLSESSION         = _V2L_SENBASE + 5;
  _V2LMSG_FIRSTFREE          = _V2L_SENBASE + 6;

  // Messages that a VSL sends to Visio:
  L2VMSG_AVAILCALLS          = _L2V_INVBASE;     // Not for external use.
  L2VMSG_REGADDON            = _L2V_SENBASE;
  L2VMSG_UNREGADDON          = _L2V_SENBASE + 1;
  L2VMSG_ISAOENABLED         = _L2V_SENBASE + 2;
  L2VMSG_ISCMDENABLED        = _L2V_SENBASE + 3; // Not for external use.
  L2VMSG_ENABLEMENU_obsolete = _L2V_SENBASE + 4; // Consume id for backwards compatibility.
  L2VMSG_ISCMDQUERY_obsolete = _L2V_SENBASE + 5; // Consume id for backwards compatibility.
  L2VMSG_GETARGSIZE          = _L2V_SENBASE + 6; // Not for external use.
  L2VMSG_AVAILMODES_obsolete = _L2V_SENBASE + 7; // Consume id for backwards compatibility.
  L2VMSG_EXECUTE             = _L2V_SENBASE + 8; // Not for external use.
  L2VMSG_ENUMDOCS_obsolete   = _L2V_SENBASE + 9; // Consume id for backwards compatibility.
  L2VMSG_ENUMCONS_obsolete   = _L2V_SENBASE + 10;// Consume id for backwards compatibility.
  L2VMSG_ENUMSHEETS_obsolete = _L2V_SENBASE + 11;// Consume id for backwards compatibility.
  L2VMSG_SESSIONDONE         = _L2V_SENBASE + 12;
  L2VMSG_PROMPTUSER_obsolete = _L2V_SENBASE + 13;// Consume id for backwards compatibility.
  L2VMSG_DBL2ASCII_obsolete  = _L2V_SENBASE + 14;// Consume id for backwards compatibility.
  L2VMSG_ASCII2DBL_obsolete  = _L2V_SENBASE + 15;// Consume id for backwards compatibility.
  L2VMSG_GETAPPINFO_obsolete = _L2V_SENBASE + 16;// Consume id for backwards compatibility.
  L2VMSG_DEBUGMSG_obsolete   = _L2V_SENBASE + 17;// Consume id for backwards compatibility.

  // --values below here were added to Visio 4.0--
  L2VMSG_BINDDATA            = _L2V_SENBASE + 18;
  L2VMSG_BOUNDDATA           = _L2V_SENBASE + 19;

  _L2VMSG_FIRSTFREE          = _L2V_SENBASE + 20;

// --------------------
// GENERIC RETURN CODES
// --------------------

const
  VAORC_SUCCESS              = _VAOGEN_INVBASE + 0; // ASSERT(VAORC_SUCCESS==0);
  VAORC_FAILURE              = _VAOGEN_SENBASE + 0;
  VAORC_L2V_LOADFAILED       = _L2V_INVBASE + 0;    // Error for V2LMSG_LOAD.
  VAORC_L2V_ENABLED          = _L2V_SENBASE + 0;    // True for V2LMSG_ISAOENABLED (else 0)
  VAORC_L2V_MODELESS         = _L2V_SENBASE + 1;    // For V2LMSG_RUNxxx
  VAORC_L2V_GOTNOABOUT       = _L2V_SENBASE + 2;    // For V2LMSG_RUNABOUT
  VAORC_L2V_GOTNOHELP        = _L2V_SENBASE + 3;    // For V2LMSG_RUNHELP
  VAORC_L2V_BADMSG           = _L2V_SENBASE + 5;    // If sent illegal message.

  VAO_L2V_VERSION = ((VAO_IFMAJOR shl 8) or VAO_IFMINOR);

//======================================
              implementation
//======================================

end.

