unit DAVSLEvents_Control;
{-----------------------------------------------------------
Demo of DAVSL VSL Framework
www.diagramantics.com

Demonstrates a VSL which monitors events and reports them to a
VSL window.

2000-09-20 GW
------------------------------------------------------------}
interface
uses DAVAO, Visio_TLB, DAVisioAddOnSink_TLB, DAVSLEvents_Events ;
Type
  //-----------------------
  TEventController = class
  //-----------------------
  private
    SaveSessId       : word;

    EventSink        : TVisioAddOnSink;
    EventSinkInt     : IVisioAddOnSink; // needed to avoid release

    ConnAddedEvent   : Visio_TLB.Event;
    ConnDeletedEvent : Visio_TLB.Event;

  public
    App       : Visio_TLB.Application;
    constructor Create; 

    procedure EnableEventMonitoring;
    procedure DisableEventMonitoring;
    //-----------------------------------------
    // Addon housekeeping methods
    //-----------------------------------------
    function Show_LOAD(visApp: Visio_TLB.Application): TVAORC;
    function Show_UNLOAD(): TVAORC;
    function Show_KILLSESSION(SessionId: word): TVAORC;
    //-----------------------------------------
    // Addon RUN methods
    //-----------------------------------------
    function Show_RUN(SessionId: word): TVAORC;
    function Hide_RUN(): TVAORC;

    //-----------------------------------------
    // Event responses
    //-----------------------------------------
    procedure OnConnAddDel(AConnects: Connects; EventWord: word);
  end;

Var
  EventController: TEventController;

implementation
uses Forms, dialogs, sysutils, DAVSLEvents_Form;
//-----------------------------------------------
constructor TEventController.Create;
//-----------------------------------------------
begin
  SaveSessId       := 0;

  EventSink        := nil;
  EventSinkInt     := nil;

  ConnAddedEvent   := nil;
  ConnDeletedEvent := nil;
end;

//-----------------------------------------------
procedure TEventController.DisableEventMonitoring;
//-----------------------------------------------
Begin
  try
  If Assigned(ConnAddedEvent) then
  Begin
    ConnAddedEvent.Delete;
    ConnAddedEvent := nil;
  end;
  If Assigned(ConnDeletedEvent) then
  Begin
    ConnDeletedEvent.Delete;
    ConnDeletedEvent := nil;
  end;
  except
    on E: Exception do
    Begin
      MessageDlg('Unhook Event failed ' + E.Message, mtInformation, [mbOk], 0);
    end;
  end;
end;

//-----------------------------------------------
procedure TEventController.EnableEventMonitoring;
//-----------------------------------------------
Var
  EventList: Visio_TLB.EventList;
  W: word;
  UnkForVisio: IUnknown;
begin
  try
    if not assigned(ConnAddedEvent) then
    Begin
      EventList := App.EventList;
      W := visConnAdd;
      UnkForVisio := EventSink as IUnknown;
      ConnAddedEvent   := EventList.AddAdvise(W, UnkForVisio, WideString(''), WideString(''));
    end;
    if not assigned(ConnDeletedEvent) then
    Begin
      EventList := App.EventList;
      W := visConnDel;
      UnkForVisio := EventSink as IUnknown;
      ConnDeletedEvent := EventList.AddAdvise(W, UnkForVisio, WideString(''), WideString(''));
    end;
  except
    on E: Exception do
    Begin
      MessageDlg('Hookup Event failed ' + E.Message, mtInformation, [mbOk], 0);
    end;
  end;
end;

//----------------------------------------------------------
function TEventController.Show_LOAD(visApp: Visio_TLB.Application): TVAORC;
//----------------------------------------------------------
Begin
  App := visApp;
  EventSink    := TVisioAddOnSink.Create;
  EventSinkInt := EventSink;  // need at least one reference to avoid release
                              // Note Delphi converts from Txxx to Ixxx

  Result := VAORC_SUCCESS;
end;


//-----------------------------------------------
function TEventController.Show_RUN(SessionId: word): TVAORC;
//-----------------------------------------------
Var
  S: string;
  N: integer;
begin
  Result := VAORC_SUCCESS;
  try
    //------------------------------------------
    // Open the form if it's not already
    //------------------------------------------
    If Not Assigned(Form1) then
    Begin
      SaveSessID := SessionId;
      Form1 := TForm1.Create(Forms.Application);
      Form1.Show;
      EnableEventMonitoring;
      Result := VAORC_L2V_MODELESS;
    end;

  except
    MessageDlg('Error running AddOn', mtInformation, [mbOk], 0);
    Form1.Free;
    Form1 := nil;
  end;
end;

//-----------------------------------------------
function TEventController.Show_UNLOAD: TVAORC;
//-----------------------------------------------
begin
  If Assigned(Form1) then
  Begin
    try
      DisableEventMonitoring;
      Form1.Close;
    except
    end;
  end;
  Result := VAORC_SUCCESS;
end;

//-----------------------------------------------
function TEventController.Show_KILLSESSION(SessionId: word): TVAORC;
//-----------------------------------------------
begin
  Result := VAORC_SUCCESS;
  If Assigned(Form1) then
  Begin
    if SaveSessID = SessionId then
    Begin
      try
        DisableEventMonitoring;
        //----------------------------------------------
        // This seems like the right thing to do but
        // we don't know when Visio sends this message
        // and whether Window relationships are still
        // valid at this point, so could exception
        // Hence try..except block
        //----------------------------------------------
        Form1.Close;
      except
      end;
    end;
  end;
end;

//-----------------------------------------------
function TEventController.Hide_RUN: TVAORC;
//-----------------------------------------------
begin
  try
    DisableEventMonitoring;
    If Assigned(Form1) then Form1.Close;
  except
  end;
end;

//-----------------------------------------------
procedure TEventController.OnConnAddDel(AConnects: Connects;  EventWord: word);
//-----------------------------------------------
Var
  S: string;
  FromShape, ToShape: Visio_TLB.Shape;
  AConnect: Visio_TLB.Connect;
Label the_end;
begin
  If Assigned(Form1) then
  Begin
    S := '';
    Case EventWord of
      visConnAdd: S := S + 'ConnAdd ';
      visConnDel: S := S + 'ConnDel ';
    end;
    if not Assigned(AConnects) then goto the_end;
    AConnect := AConnects[1];
    if not Assigned(AConnect) then goto the_end;
    FromShape := AConnect.FromSheet;
    ToShape   := AConnect.ToSheet;
    S := S + 'From ' + FromShape.NameId + ' to ' + ToShape.NameId;
    Form1.Memo1.Lines.Add(S);
  end;  
the_end:
end;

initialization
  EventController := TEventController.Create;
end.

